==> babel-live-1.4.0.tgz: package/lib/cli.js <==
'use strict';

let getPackage = (() => {
  var ref = _asyncToGenerator(function* () {
    try {
      const content = yield (0, _fs.readFile)(_path2.default.resolve(process.cwd(), 'package.json'));
      return JSON.parse(content);
    } catch (error) {
      return {};
    }
  });

  return function getPackage() {
    return ref.apply(this, arguments);
  };
})();

let main = (() => {
  var ref = _asyncToGenerator(function* (input, flags) {
    if (!input) {
      const error = new Error('[input] module is required.');
      error.cli = true;
      throw error;
    }

    const basedir = process.cwd();

    const inputPath = yield resolve(input, { basedir: basedir });
    const cwd = _path2.default.dirname(inputPath);

    const pkg = _findConfig2.default.read('package.json', { cwd: cwd });
    const rcOptions = (0, _rcfile2.default)('babel', { cwd: cwd });

    const options = (0, _lodash2.default)({}, pkg.babel, rcOptions, flags.babel);
    return (0, _2.default)(inputPath, flags, (0, _lodash4.default)(options, ['_']));
  });

  return function main(_x, _x2) {
    return ref.apply(this, arguments);
  };
})();

require('babel-polyfill');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('mz/fs');

var _denodeify = require('denodeify');

var _denodeify2 = _interopRequireDefault(_denodeify);

var _meow = require('meow');

var _meow2 = _interopRequireDefault(_meow);

var _resolve = require('resolve');

var _resolve2 = _interopRequireDefault(_resolve);

var _lodash = require('lodash.merge');

var _lodash2 = _interopRequireDefault(_lodash);

var _lodash3 = require('lodash.omit');

var _lodash4 = _interopRequireDefault(_lodash3);

var _rcfile = require('rcfile');

var _rcfile2 = _interopRequireDefault(_rcfile);

var _findConfig = require('find-config');

var _findConfig2 = _interopRequireDefault(_findConfig);

var _ = require('./');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

const resolve = (0, _denodeify2.default)(_resolve2.default);

const cli = (0, _meow2.default)(`
  Usage
    $ babel-live [input] <args>

  Options
`);

main(cli.input[0], cli.flags).catch(error => {
  if (error.cli) {
    console.error(error.message);
    return cli.showHelp(1);
  }
  setTimeout(() => {
    throw error;
  });
});

==> babel-live-1.5.0.tgz: package/lib/cli.js <==
#!/usr/bin/env node
'use strict';

let getPackage = (() => {
  var ref = _asyncToGenerator(function* () {
    try {
      const content = yield (0, _fs.readFile)(_path2.default.resolve(process.cwd(), 'package.json'));
      return JSON.parse(content);
    } catch (error) {
      return {};
    }
  });

  return function getPackage() {
    return ref.apply(this, arguments);
  };
})();

let main = (() => {
  var ref = _asyncToGenerator(function* (input, flags) {
    if (!input) {
      const error = new Error('[input] module is required.');
      error.cli = true;
      throw error;
    }

    const basedir = process.cwd();

    const inputPath = yield resolve(input, { basedir });
    const cwd = _path2.default.dirname(inputPath);

    const pkg = _findConfig2.default.read('package.json', { cwd });
    const rcOptions = (0, _rcfile2.default)('babel', { cwd });

    const options = (0, _lodash2.default)({}, pkg.babel, rcOptions, flags.babel);
    return (0, _2.default)(inputPath, flags, (0, _lodash4.default)(options, ['_']));
  });

  return function main(_x, _x2) {
    return ref.apply(this, arguments);
  };
})();

require('babel-polyfill');

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('mz/fs');

var _denodeify = require('denodeify');

var _denodeify2 = _interopRequireDefault(_denodeify);

var _meow = require('meow');

var _meow2 = _interopRequireDefault(_meow);

var _resolve = require('resolve');

var _resolve2 = _interopRequireDefault(_resolve);

var _lodash = require('lodash.merge');

var _lodash2 = _interopRequireDefault(_lodash);

var _lodash3 = require('lodash.omit');

var _lodash4 = _interopRequireDefault(_lodash3);

var _rcfile = require('rcfile');

var _rcfile2 = _interopRequireDefault(_rcfile);

var _findConfig = require('find-config');

var _findConfig2 = _interopRequireDefault(_findConfig);

var _ = require('./');

var _2 = _interopRequireDefault(_);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

const resolve = (0, _denodeify2.default)(_resolve2.default);

const cli = (0, _meow2.default)(`
  Usage
    $ babel-live [input] <args>

  Options
`);

main(cli.input[0], cli.flags).catch(error => {
  if (error.cli) {
    console.error(error.message);
    return cli.showHelp(1);
  }
  setTimeout(() => {
    throw error;
  });
});
